# OctoBot-Commons [1.0.0](https://github.com/Drakkar-Software/OctoBot-Commons/tree/master/docs/CHANGELOG.md)
[![PyPI](https://img.shields.io/pypi/v/OctoBot-Commons.svg)](https://pypi.python.org/pypi/OctoBot-Commons/)
[![Build Status](https://api.travis-ci.com/Drakkar-Software/OctoBot-Commons.svg?branch=master)](https://travis-ci.org/Drakkar-Software/OctoBot-Commons) 

[OctoBot](https://github.com/Drakkar-Software/OctoBot) project common modules.
